
%define _libdir64 %{_prefix}/lib64

Name:           libburn
Version:        1.4.8
Release:        1
Summary:        Library for reading, mastering and writing optical discs
Group:          System Environment/Libraries
License:        GPLv2
URL:            http://libburnia-project.org/
Source0:        http://files.libburnia-project.org/releases/%{name}-%{version}.tar.gz
Source1:        http://files.libburnia-project.org/releases/%{name}-%{version}.tar.gz.sig
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:  doxygen graphviz

%description
Libburn is an open-source library for reading, mastering and writing
optical discs. For now this means only CD-R and CD-RW.

The project comprises of several more or less interdependent parts which
together strive to be a usable foundation for application development.
These are libraries, language bindings, and middleware binaries which emulate
classical (and valuable) Linux tools.

The library is available as 32-bit and 64-bit.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       pkg-config

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".


%package -n     cdrskin
Summary:        Limited cdrecord compatibility wrapper to ease migration to libburn
Group:          Applications/Multimedia
Requires:       %{name} = %{version}-%{release}

%description -n cdrskin
A limited cdrecord compatibility wrapper which allows to use some libburn 
features from the command line.


%prep
%setup -q
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static
make %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static
make %{?_smp_mflags}

doxygen doc/doxygen.conf


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
make DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
make DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a ${RPM_BUILD_ROOT}%{_libdir64}/%{name}.so*

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc 32bit/AUTHORS 32bit/COPYING 32bit/COPYRIGHT 32bit/README
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files devel
%defattr(-,root,system,-)
%doc 32bit/doc/html
%{_includedir}/*
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/pkgconfig/*.pc
%{_libdir64}/pkgconfig/*.pc
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%files -n cdrskin
%defattr(-,root,system,-)
%{_bindir}/cdrskin
%{_mandir}/man?/*
/usr/bin/cdrskin


%changelog
* Fri Dec 15 2017 Michael Perzl <michael@perzl.org> - 1.4.8-1
- updated to version 1.4.8

* Mon Sep 19 2016 Michael Perzl <michael@perzl.org> - 1.4.6-1
- updated to version 1.4.6

* Sun Jul 03 2016 Michael Perzl <michael@perzl.org> - 1.4.4-1
- updated to version 1.4.4

* Wed Feb 03 2016 Michael Perzl <michael@perzl.org> - 1.4.2.pl01-1
- updated to version 1.4.2.pl01

* Wed Feb 03 2016 Michael Perzl <michael@perzl.org> - 1.4.0-1
- updated to version 1.4.0

* Wed Feb 03 2016 Michael Perzl <michael@perzl.org> - 1.3.8-1
- updated to version 1.3.8

* Wed Mar 19 2014 Michael Perzl <michael@perzl.org> - 1.3.6.pl01-1
- updated to version 1.3.6.pl01

* Thu Dec 12 2013 Michael Perzl <michael@perzl.org> - 1.3.4-1
- updated to version 1.3.4

* Wed Aug 07 2013 Michael Perzl <michael@perzl.org> - 1.3.2-1
- updated to version 1.3.2

* Fri May 03 2013 Michael Perzl <michael@perzl.org> - 1.2.8-1
- updated to version 1.2.8

* Tue Jan 08 2013 Michael Perzl <michael@perzl.org> - 1.2.4-1
- updated to version 1.2.4

* Tue May 29 2012 Michael Perzl <michael@perzl.org> - 1.2.2-1
- updated to version 1.2.2

* Thu Apr 19 2012 Michael Perzl <michael@perzl.org> - 1.1.8-1
- updated to version 1.1.8

* Mon May 02 2011 Michael Perzl <michael@perzl.org> - 1.0.6-1
- first version for AIX V5.1 and higher
